from __future__ import division
import numpy as np
cimport numpy as np

cimport cython
@cython.boundscheck(False)  # Deactivate bounds checking
@cython.wraparound(False)   # Deactivate negative indexing.
def calc_julia(int im_width, int im_height, int xmin, int xmax, int ymin, int ymax, float zabs_max, int nit_max, complex c):
    #
    cdef np.ndarray[np.float32_t, ndim=1] X
    X = np.linspace(xmin, xmax, im_width, dtype=np.float32)
    cdef np.ndarray[np.float32_t, ndim=1] Y
    Y = np.linspace(ymin  , ymax, im_height, dtype=np.float32)
    cdef np.ndarray[np.complex64_t, ndim=2] Z
    Z = X + Y[:, None]*1j
    cdef np.ndarray[np.int32_t, ndim=2] N
    N = np.zeros((im_width,im_height), dtype=np.int32)
    cdef np.ndarray[np.float32_t, ndim=2] ratio
    ratio = np.zeros((im_width,im_height), dtype=np.float32)
    cdef np.ndarray[np.complex64_t, ndim=2] C
    C = np.zeros((im_width,im_height), np.complex64) + c
    cdef int n
    for n in range(nit_max):
        I = np.less(abs(Z), zabs_max)
        N[I] = n
        Z[I] = Z[I]**2 + C[I]
    N[N == nit_max-1] = 0
    ratio = (N / nit_max).astype(np.float32)
    return ratio

