#!/usr/bin/env python
from __future__ import division
import numpy as np
import matplotlib.pyplot as plt
import matplotlib.cm as cm

import pyjulia
import pyjulia_numpy
import julia as cythonjulia
import juliaraw
import time


## call the different versions as
## pyjulia.calc_julia
## pyjulia_numpy.calc_julia

if __name__ == '__main__':
    COMPARISON=True
    # Image width and height; parameters for the plot
    im_width, im_height = 1000, 1000
    c = complex(-0.1, 0.65)
    zabs_max = 10
    nit_max = 2000
    xmin, xmax = -1.5, 1.5
    ymin, ymax = -1.5, 1.5
    xwidth = xmax - xmin
    yheight = ymax - ymin
    if COMPARISON:
        start = time.time()
        julia = pyjulia.calc_julia(im_width, im_height, xmin, xmax, ymin, ymax, zabs_max, nit_max, c)
        end1= time.time()
        julia = pyjulia_numpy.calc_julia_numpy(im_width, im_height, xmin, xmax, ymin, ymax, zabs_max, nit_max, c)
        end2= time.time()
        julia = cythonjulia.calc_julia(im_width, im_height, xmin, xmax, ymin, ymax, zabs_max, nit_max, c)
        end3 = time.time()
        julia = juliaraw.calc_julia(im_width, im_height, xmin, xmax, ymin, ymax, zabs_max, nit_max, c)
        end4 = time.time()
        print "Total time used:",end3-start
        print "Raw python:     ",end1-start
        print "Numpy python:   ",end2-end1
        print "Numpy cython:   ",end3-end2
        print "Raw cython:     ",end4-end3
    else:
        julia = cythonjulia.calc_julia(im_width, im_height, xmin, xmax, ymin, ymax, zabs_max, nit_max, c)
        
    fig, ax = plt.subplots()
    ax.imshow(julia, interpolation="bicubic", cmap=cm.hot)
    # Set the tick labels to the coordinates of z0 in the complex plane
    xtick_labels = np.linspace(xmin, xmax, xwidth / 0.5)
    ax.set_xticks([(x-xmin) / xwidth * im_width for x in xtick_labels])
    ax.set_xticklabels(['{:.1f}'.format(xtick) for xtick in xtick_labels])
    ytick_labels = np.linspace(ymin, ymax, yheight / 0.5)
    ax.set_yticks([(y-ymin) / yheight * im_height for y in ytick_labels])
    ax.set_yticklabels(['{:.1f}'.format(ytick) for ytick in ytick_labels])
    plt.show()

    
